<?php
/**
 * Custom views handler for news_client_image_json field.
 */

class news_client_views_handler_field_news_client_image_json extends views_handler_field {
  
  /**
   * {@inheritDoc}
   * @see views_handler_field::option_definition()
   */
  function option_definition() {
    $options = parent::option_definition();
    
    $options['display_caption'] = array(
      'default' => FALSE,
      'bool' => TRUE,
    );
    
    return $options;
  }
  
  /**
   * {@inheritDoc}
   * @see views_handler_field::options_form()
   */
  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);
    
    $form['display_caption'] = array(
      '#type' => 'checkbox',
      '#title' => t('Display Caption'),
      '#description' => t('Display caption with image if available?'),
      '#default_value' => $this->options['display_caption'],
    );
  }
  
  /**
   * {@inheritDoc}
   * @see views_handler_field::render()
   */
  function render($values) {
    $nid = $this->get_value($values);
    
    $query = new EntityFieldQuery();
    $query->entityCondition('entity_type', 'node');
    $query->entityCondition('bundle', 'news_client_cached_article');
    $query->propertyCondition('nid', $nid, '=');
    
    $result = $query->execute();
    
    $rendered_markup = '';
    
    if (isset($result['node'])) {
      $cached_article_nids = array_keys($result['node']);
      $cached_article_nid = array_shift($cached_article_nids);
      
      $cached_article = entity_load_single('node', $cached_article_nid);
      
      $ca_wrapper = NULL;
      
      try {
        $ca_wrapper = entity_metadata_wrapper('node', $cached_article);
      }
      catch (Exception $e) {
        _news_client_entitymetadatawrapper_exception($e);
      }
      
      $image_json = '';
      
      try {
        $image_json = $ca_wrapper->news_client_image_json->value();
      }
      catch (Exception $e) {
        _news_client_entitymetadatawrapper_exception($e);
      }
      
      $image_data = json_decode($image_json);
      
      $image_markup = '';
      $caption_text = '';
      
      foreach ($image_data as $image) {
        $data = array(
          'path' => $image->url,
          'alt' => $image->alt,
          'title' => $image->title,
          'attributes' => array(
            'class' => array('news_client_image_json'),
          ),
        );
        $image_markup .= theme_image($data);
        $caption_text = isset($image->caption) ? $image->caption : '';
      }
      
      $display_caption = (empty($caption_text)) ? FALSE : $this->options['display_caption'];
      
      $r_array = array(
        '#theme' => 'news_client_image_json',
        '#image_markup' => $image_markup,
        '#caption_text' => $caption_text,
        '#display_caption' => $display_caption,
      );
      
      $rendered_markup = render($r_array);
    }
    
    return $rendered_markup;
  }
}
